src/c/so3_core.h Source File

# so3_core.h

Go to the documentation of this file.

    00001 // S03 package to perform Wigner transform on the rotation group SO(3)
    00002 // Copyright (C) 2013 Martin Büttner and Jason McEwen
    00003 // See LICENSE.txt for license details
    00004
    00005 #ifndef SO3_CORE
    00006 #define SO3_CORE
    00007
    00008 #include "ssht.h"
    00009 #include <complex.h>
    00010
    00011 void so3_core_inverse_via_ssht(
    00012     complex double *f, const complex double *flmn,
    00013     const so3_parameters_t *parameters
    00014 );
    00015
    00016 void so3_core_forward_via_ssht(
    00017     complex double *flmn, const complex double *f,
    00018     const so3_parameters_t *parameters
    00019 );
    00020
    00021 void so3_core_inverse_via_ssht_real(
    00022     double *f, const complex double *flmn,
    00023     const so3_parameters_t *parameters
    00024 );
    00025
    00026 void so3_core_forward_via_ssht_real(
    00027     complex double *flmn, const double *f,
    00028     const so3_parameters_t *parameters
    00029 );
    00030
    00031
    00032
    00033 void so3_core_inverse_direct(
    00034     complex double *f, const complex double *flmn,
    00035     const so3_parameters_t *parameters
    00036 );
    00037
    00038 void so3_core_forward_direct(
    00039     complex double *flmn, const complex double *f,
    00040     const so3_parameters_t *parameters
    00041 );
    00042
    00043 void so3_core_inverse_direct_real(
    00044     double *f, const complex double *flmn,
    00045     const so3_parameters_t *parameters
    00046 );
    00047
    00048 void so3_core_forward_direct_real(
    00049     complex double *flmn, const double *f,
    00050     const so3_parameters_t *parameters
    00051 );
    00052
    00053 #endif